@@ -10,7 +10,7 @@ import twitter
 
 
 register = template.Library()
-tweet_parser = ttp.Parser()
+tweet_parser = ttp.Parser(max_url_length=60)
 
 
 def get_cache_key(*args):
@@ -19,8 +19,9 @@ def get_cache_key(*args):
 
 @tag(register, [Constant("for"), Variable(), Constant("as"), Name(),
                 Optional([Constant("exclude"), Variable("exclude")]),
+                Optional([Constant("expandurls"), Variable("expandurls")]),
                 Optional([Constant("limit"), Variable("limit")])])
-def get_tweets(context, username, asvar, exclude='', limit=None):
+def get_tweets(context, username, asvar, exclude='', expandurls=True, limit=None):
     cache_key = get_cache_key(username, asvar, exclude, limit)
     tweets = []
     try:
@@ -36,7 +37,16 @@ def get_tweets(context, username, asvar, exclude='', limit=None):
         if 'replies' in exclude and status.GetInReplyToUserId() is not None:
             continue
 
-        status.html = tweet_parser.parse(status.GetText()).html
+        if status.retweeted_status:
+            text = u'RT @%s: %s' % (status.retweeted_status.user.screen_name, status.retweeted_status.text)
+            urls = status.retweeted_status.urls
+        else:
+            text = status.GetText()
+            urls = status.urls
+        if expandurls and urls:
+            for status_url in urls:
+                text = text.replace(status_url.url, status_url.expanded_url)
+        status.html = tweet_parser.parse(text).html
         tweets.append(status)
 
     if limit:
